@@ -7,7 +7,7 @@
  */
 
 /*
- * Copyright (C) 1995 - 2001, 2003-2013 the Free Software Foundation, Inc.
+ * Copyright (C) 1995 - 2001, 2003-2014 the Free Software Foundation, Inc.
  * 
  * This file is part of GAWK, the GNU implementation of the
  * AWK Programming Language.
@@ -46,33 +46,9 @@ extern SRCFILE *srcfiles;
 static bool
 is_letter(unsigned char c)
 {
-	switch (c) {
-	case 'a': case 'b': case 'c': case 'd': case 'e': case 'f':
-	case 'g': case 'h': case 'i': case 'j': case 'k': case 'l':
-	case 'm': case 'n': case 'o': case 'p': case 'q': case 'r':
-	case 's': case 't': case 'u': case 'v': case 'w': case 'x':
-	case 'y': case 'z':
-	case 'A': case 'B': case 'C': case 'D': case 'E': case 'F':
-	case 'G': case 'H': case 'I': case 'J': case 'K': case 'L':
-	case 'M': case 'N': case 'O': case 'P': case 'Q': case 'R':
-	case 'S': case 'T': case 'U': case 'V': case 'W': case 'X':
-	case 'Y': case 'Z':
-	case '_':
-		return true;
-	default:
-		return false;
-	}
+	return (is_alpha(c) || c == '_');
 }
 
-/* is_identifier_char --- return true if a character can be used in an identifier */
-
-static bool
-is_identifier_char(unsigned char c)
-{
-	return (is_letter(c) || isdigit(c));
-}
-
-
 #define INIT_FUNC	"dl_load"
 
 /* load_ext --- load an external library */
@@ -174,9 +150,9 @@ load_old_ext(SRCFILE *s, const char *init_func, const char *fini_func, NODE *obj
 		fatal(_("`extension' is a gawk extension"));
 
 	if (lib_name == NULL)
-		fatal(_("load_ext: received NULL lib_name"));
+		fatal(_("extension: received NULL lib_name"));
 
-	if ((dl = dlopen(s->fullpath, flags)) == NULL)
+	if ((dl = dlopen(lib_name, flags)) == NULL)
 		fatal(_("extension: cannot open library `%s' (%s)"), lib_name,
 		      dlerror());
 
@@ -221,13 +197,11 @@ make_builtin(const awk_ext_func_t *funcinfo)
 		fatal(_("make_builtin: missing function name"));
 
 	if (! is_letter(*sp))
-		return false;
+		return awk_false;
 
-	sp++;
-
-	while ((c = *sp++) != '\0') {
-		if (! is_identifier_char(c))
-			return false;
+	for (sp++; (c = *sp++) != '\0';) {
+		if (! is_identchar(c))
+			return awk_false;
 	}
 
 	f = lookup(name);
@@ -240,7 +214,7 @@ make_builtin(const awk_ext_func_t *funcinfo)
 			/* multiple extension() calls etc. */ 
 			if (do_lint)
 				lintwarn(_("make_builtin: function `%s' already defined"), name);
-			return false;
+			return awk_false;
 		} else
 			/* variable name etc. */ 
 			fatal(_("make_builtin: function name `%s' previously defined"), name);
@@ -260,7 +234,7 @@ make_builtin(const awk_ext_func_t *funcinfo)
        	symbol = install_symbol(estrdup(name, strlen(name)), Node_ext_func);
 	symbol->code_ptr = b;
 	track_ext_func(name);
-	return true;
+	return awk_true;
 }
 
 /* make_old_builtin --- register name to be called as func with a builtin body */
@@ -277,9 +251,11 @@ make_old_builtin(const char *name, NODE *(*func)(int), int count)	/* temporary *
 	if (sp == NULL || *sp == '\0')
 		fatal(_("extension: missing function name"));
 
-	while ((c = *sp++) != '\0') {
-		if ((sp == & name[1] && c != '_' && ! isalpha((unsigned char) c))
-				|| (sp > &name[1] && ! is_identifier_char((unsigned char) c)))
+	if (! is_letter(*sp))
+		fatal(_("extension: illegal character `%c' in function name `%s'"), *sp, name);
+
+	for (sp++; (c = *sp++) != '\0';) {
+		if (! is_identchar(c))
 			fatal(_("extension: illegal character `%c' in function name `%s'"), c, name);
 	}
 
@@ -312,6 +288,7 @@ make_old_builtin(const char *name, NODE *(*func)(int), int count)	/* temporary *
 
        	symbol = install_symbol(estrdup(name, strlen(name)), Node_old_ext_func);
 	symbol->code_ptr = b;
+	track_ext_func(name);
 }
 
 
@@ -420,6 +397,9 @@ close_extensions()
 {
 	SRCFILE *s;
 
+	if (srcfiles == NULL)
+		return;
+
 	for (s = srcfiles->next; s != srcfiles; s = s->next) 
 		if (s->stype == SRC_EXTLIB && s->fini_func)
                	        (*s->fini_func)();
